KeyedContainerBuilder

Enum KeyedContainerBuilder 

pub enum KeyedContainerBuilder<Container, Target> {
    Unspecified,
    Some(Container),
    _PhantomData(PhantomData<fn() -> Target>),
}
Builder type for keyed containers, such as HashMap (as opposed to unkeyed containers like Vec). This is not required to be used, but is a convient shortcut for map types’ implementations.

Types using this as their builder must implement KeyedContainer.

For unkeyed containers, see UnkeyedContainerBuilder.

Example usage:

use std::fmt::Display;

use confik::{
    helpers::{BuilderOf, KeyedContainer, KeyedContainerBuilder},
    Configuration,
};
use serde::Deserialize;

struct MyMap<K, V> {
    // ...
}

impl<'de, K, V> Deserialize<'de> for MyMap<K, V> {
    fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
    where
        D: serde::Deserializer<'de>,
    {
        // ...
    }
}

impl<K, V> Default for MyMap<K, V> {
    fn default() -> Self {
        // ...
    }
}

impl<K, V> IntoIterator for MyMap<K, V> {
    type Item = (K, V);

    type IntoIter = // ...

    fn into_iter(self) -> Self::IntoIter {
        // ...
    }
}

impl<'a, K, V> IntoIterator for &'a MyMap<K, V> {
    type Item = (&'a K, &'a V);

    type IntoIter = // ...

    fn into_iter(self) -> Self::IntoIter {
        // ...
    }
}

impl<K, V> FromIterator<(K, V)> for MyMap<K, V> {
    fn from_iter<I: IntoIterator<Item = (K, V)>>(iter: I) -> Self {
        // ...
    }
}

impl<K, V> KeyedContainer for MyMap<K, V> {
    type Key = K;

    type Value = V;

    fn insert(&mut self, k: Self::Key, v: Self::Value) {
        // ...
    }

    fn remove(&mut self, k: &Self::Key) -> Option<Self::Value> {
        // ...
    }
}

impl<K, V> Configuration for MyMap<K, V>
where
    K: Display + 'static,
    V: Configuration,
    BuilderOf<V>: 'static,
{
    type Builder = KeyedContainerBuilder<MyMap<K, BuilderOf<V>>, Self>;
}

Variants



Unspecified

No data has been provided yet.

Default to None but allow overwriting by later merges.



Some(Container)

Data has been provided.

Will not be overwritten by later merges.



_PhantomData(PhantomData<fn() -> Target>)

Never instantiated, used to hold the Target type.