ConfigBuilder

Struct ConfigBuilder 

pub struct ConfigBuilder<'a, Target: Configuration> { /* private fields */ }
Used to accumulate ordered sources from which its Target is to be built.

An instance of this can be created via Configuration::builder or ConfigBuilder::<T>::default.

Examples

Using Configuration::builder:

use confik::{Configuration, TomlSource};

#[derive(Debug, PartialEq, Configuration)]
struct MyConfigType {
    param: String,
}

let config = MyConfigType::builder()
    .override_with(TomlSource::new(r#"param = "Hello World""#))
    .try_build()
    .expect("Failed to build");

assert_eq!(config.param, "Hello World");

Using ConfigBuilder::<T>::default:

use confik::{ConfigBuilder, Configuration, TomlSource};

#[derive(Debug, PartialEq, Configuration)]
struct MyConfigType {
    param: String,
}

let config = ConfigBuilder::<MyConfigType>::default()
    .override_with(TomlSource::new(r#"param = "Hello World""#))
    .try_build()
    .expect("Failed to build");

assert_eq!(config.param, "Hello World");

Implementations

Source

impl<'a, Target: Configuration> ConfigBuilder<'a, Target>

pub fn override_with( &mut self, source: impl Source<Target::Builder> + 'a, ) -> &mut Self

Add a single Source to the list of sources.

The source is added at the end of the list, overriding existing sources.

use confik::{Configuration, TomlSource};
#[derive(Debug, PartialEq, Configuration)]
struct MyConfigType {
    param: String,
}

let config = MyConfigType::builder()
    .override_with(TomlSource::new(r#"param = "Hello World""#))
    .override_with(TomlSource::new(r#"param = "Hello Universe""#))
    .try_build()
    .expect("Failed to build");

assert_eq!(config.param, "Hello Universe");
pub fn try_build(&mut self) -> Result<Target, Error>

Attempt to build from the provided sources.

Errors

Returns an error if a required value is missing, a secret value was provided in a non-secret source, or an error is returned from a source (e.g., invalid TOML). See Error for more details.