OffsetSource

Struct OffsetSource 

pub struct OffsetSource<'a, OffsetBuilder, PathFn> { /* private fields */ }
A Source containing another source that can build the target at an offset determined by the provided path.

use confik::{helpers::BuilderOf, Configuration, OffsetSource, TomlSource};

#[derive(Debug, Configuration, PartialEq, Eq)]
struct Config {
    data: usize,
    leaf: LeafConfig,
}

#[derive(Debug, Configuration, PartialEq, Eq)]
struct LeafConfig {
    data: usize,
}

let root_toml = "data = 4";
let leaf_toml = "data = 5";

let root_source = TomlSource::new(root_toml);
let leaf_source = OffsetSource::new::<BuilderOf<Config>>(
    TomlSource::new(leaf_toml),
    |b| &mut b.leaf,
);

let config = Config::builder()
    .override_with(root_source)
    .override_with(leaf_source)
    .try_build()
    .expect("Valid source");

assert_eq!(
    config,
    Config {
        data: 4,
        leaf: LeafConfig { data: 5 }
    }
);

Implementations

Source

impl<'a, OffsetBuilder, PathFn> OffsetSource<'a, OffsetBuilder, PathFn>
where OffsetBuilder: ConfigurationBuilder,

pub fn new<TargetBuilder>( inner_source: impl Source<OffsetBuilder> + 'a, path: PathFn, ) -> Self
where TargetBuilder: ConfigurationBuilder, PathFn: for<'b> Fn(&'b mut TargetBuilder) -> &'b mut OffsetBuilder,

Creates a Source containing raw JSON data.